@@ -82,20 +82,22 @@ class SendEmail(Action):
                 if is_email_simple(extracted_email):
                     recipients.append(extracted_email)
         if recipients:
+            subject = (
+                engines["django"].from_string(self.subject).render({"object": object})
+            )
+            message = (
+                engines["django"].from_string(self.message).render({"object": object})
+            )
             send_mail(
-                subject=engines["django"]
-                .from_string(self.subject)
-                .render({"object": object}),
-                message=engines["django"]
-                .from_string(self.message)
-                .render({"object": object}),
+                subject=subject,
+                message=message,
                 from_email=None,
                 recipient_list=recipients,
             )
 
     class Meta:
-        verbose_name = _("Send Email Action")
-        verbose_name_plural = _("Send Email Actions")
+        verbose_name = _("Send email action")
+        verbose_name_plural = _("Send email actions")
 
 
 class Trigger(models.Model):
@@ -111,6 +113,12 @@ class Trigger(models.Model):
     filter = QuerysetField(_("Filter"), modelfieldname="model")
     enable = models.BooleanField(default=True)
     action = models.ForeignKey(Action, on_delete=models.PROTECT)
+    field = models.CharField(
+        _("Field"),
+        max_length=255,
+        blank=True,
+        help_text=_("Only trigger when a certain field has changed"),
+    )
 
     def __str__(self):
         return self.description
